@@ -49,13 +49,13 @@ has 'duration'      => ( is => 'ro', isa => ValueFromHashRef,
     required    => 1,
     );
 has 'end_address'   => ( is => 'ro', isa => 'Str' );
-has 'end_location'  => ( is => 'ro', isa => Coordinates,
+has 'end_location'  => ( is => 'ro', isa => CoordinatesClass,
     coerce      => 1,
     required    => 1,
     );
 
 has 'start_address'   => ( is => 'ro', isa => 'Str' );
-has 'start_location'  => ( is => 'ro', isa => Coordinates,
+has 'start_location'  => ( is => 'ro', isa => CoordinatesClass,
     coerce      => 1,
     required    => 1,
     );
